@@ -510,7 +510,10 @@ class _StreamResultIterator(object):
             raise
 
     def __del__(self):
-        self.close()
+        try:
+            self.close()
+        except Exception:
+            pass
 
     def close(self):
         if self.proxy and self.proxy._pyroConnection is not None:
@@ -607,13 +610,20 @@ class SerializedBlob(object):
         self.info = info
         self._data = data
         self._contains_blob = is_blob
+        if is_blob and not isinstance(data, (protocol.SendingMessage, protocol.ReceivingMessage)):
+            raise TypeError("data should be a protocol message object if is_blob is true")
 
     def deserialized(self):
         """Retrieves the client data stored in this blob. Deserializes the data automatically if required."""
         if self._contains_blob:
             protocol_msg = self._data
             serializer = serializers.serializers_by_id[protocol_msg.serializer_id]
-            _, _, data, _ = serializer.loads(protocol_msg.data)
+            if isinstance(protocol_msg, protocol.ReceivingMessage):
+                _, _, data, _ = serializer.loads(protocol_msg.data)
+            else:
+                # strip off header bytes from SendingMessage
+                payload_data = memoryview(protocol_msg.data)[protocol._header_size:]
+                _, _, data, _ = serializer.loads(payload_data)
             return data
         else:
             return self._data
